@@ -1,19 +1,21 @@
 import unittest
-from datetime import datetime
 from time import time_ns
 from unittest.mock import patch
 from uuid import uuid1
 
-from uuid6 import DraftUUID, uuid6, uuid7
+from uuid6 import UUID, uuid6, uuid7
 
+REGEX_UUID6 = r"^[0-9a-f]{8}-[0-9a-f]{4}-6[0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}$"
+REGEX_UUID7 = r"^[0-9a-f]{8}-[0-9a-f]{4}-7[0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}$"
 YEAR_IN_NS = 3600 * 24 * 36525 * 10**7
 
 
-class DraftUUIDTests(unittest.TestCase):
+class UUIDTests(unittest.TestCase):
     def test_uuid6_generation(self):
         uuid6_1 = uuid6()
         self.assertEqual(uuid6_1.version, 6)
         for _ in range(1000):
+            self.assertRegex(str(uuid6_1), REGEX_UUID6)
             uuid6_2 = uuid6()
             self.assertLess(uuid6_1, uuid6_2)
             uuid6_1 = uuid6_2
@@ -22,26 +24,27 @@ class DraftUUIDTests(unittest.TestCase):
         uuid7_1 = uuid7()
         self.assertEqual(uuid7_1.version, 7)
         for _ in range(1000):
+            self.assertRegex(str(uuid7_1), REGEX_UUID7)
             uuid7_2 = uuid7()
             self.assertLess(uuid7_1, uuid7_2)
             uuid7_1 = uuid7_2
 
     def test_invalid_int(self):
         with self.assertRaises(ValueError):
-            _ = DraftUUID(int=-1)
+            _ = UUID(int=-1)
         with self.assertRaises(ValueError):
-            _ = DraftUUID(int=1 << 128)
+            _ = UUID(int=1 << 128)
 
     def test_valid_int(self):
-        test_uuid = DraftUUID(int=0)
+        test_uuid = UUID(int=0)
         self.assertEqual(test_uuid.version, None)
         self.assertEqual(test_uuid.time, 0)
-        test_uuid = DraftUUID(int=(1 << 128) - 1)
+        test_uuid = UUID(int=(1 << 128) - 1)
         self.assertEqual(test_uuid.version, None)
 
     def test_invalid_version(self):
         with self.assertRaises(ValueError):
-            _ = DraftUUID(int=1, version=420)
+            _ = UUID(int=1, version=420)
 
     @patch("uuid6._last_v7_timestamp", 1)
     @patch("time.time_ns", return_value=1234)
@@ -72,7 +75,7 @@ class DraftUUIDTests(unittest.TestCase):
     def test_uuid6_far_in_future(self):
         with patch("time.time_ns", return_value=1):
             uuid_prev = uuid6()
-        for i in range(1, 3260):
+        for i in range(1, 3260, 10):
             with patch("time.time_ns", return_value=i * YEAR_IN_NS):
                 uuid_cur = uuid6()
                 self.assertLess(uuid_prev, uuid_cur)
@@ -87,17 +90,12 @@ class DraftUUIDTests(unittest.TestCase):
     def test_uuid7_far_in_future(self):
         with patch("time.time_ns", return_value=1):
             uuid_prev = uuid7()
-        for i in range(1, 2170):
+        for i in range(1, 8000, 10):
             with patch("time.time_ns", return_value=i * YEAR_IN_NS):
                 uuid_cur = uuid7()
                 self.assertLess(uuid_prev, uuid_cur)
                 uuid_prev = uuid_cur
 
-        # Overflow after 2 ** 36 seconds
-        with patch("time.time_ns", return_value=2178 * YEAR_IN_NS):
-            uuid_2178_from_epoch = uuid7()
-        self.assertLess(uuid_2178_from_epoch, uuid_prev)
-
     def test_time(self):
         uuid_1 = uuid1()
         uuid_6 = uuid6()
@@ -106,27 +104,21 @@ class DraftUUIDTests(unittest.TestCase):
         uuid_7 = uuid7()
         self.assertAlmostEqual(uuid_7.time / 10**9, cur_time / 10**9, 3)
 
-    def test_time_zero(self):
-        uuid_6 = DraftUUID(hex="00000000-0000-6000-8000-000000000000")
+    def test_zero_time(self):
+        uuid_6 = UUID(hex="00000000-0000-6000-8000-000000000000")
         self.assertEqual(uuid_6.time, 0)
-        uuid_7 = DraftUUID(hex="00000000-0000-7000-8000-000000000000")
+        uuid_7 = UUID(hex="00000000-0000-7000-8000-000000000000")
         self.assertEqual(uuid_7.time, 0)
 
-    def test_time_max(self):
-        uuid_6 = DraftUUID(hex="ffffffff-ffff-6fff-bfff-ffffffffffff")
+    def test_max_time(self):
+        uuid_6 = UUID(hex="ffffffff-ffff-6fff-bfff-ffffffffffff")
         self.assertEqual(uuid_6.time, 1152921504606846975)
-        uuid_7 = DraftUUID(hex="ffffffff-ffff-7fff-bfff-ffffffffffff")
-        self.assertEqual(uuid_7.time, 68719476736000000000)
-        dt = datetime.utcfromtimestamp(uuid_7.time / 10**9)
-        self.assertEqual(dt, datetime(4147, 8, 20, 7, 32, 16))
-
-    def test_uuid7_from_hex(self):
-        uuid_7 = DraftUUID(hex="061d0edc-bea0-75cc-9892-f6295fd7d295")
-        self.assertEqual(uuid_7.time, 1641082315914150976)
+        uuid_7 = UUID(hex="ffffffff-ffff-7fff-bfff-ffffffffffff")
+        self.assertEqual(uuid_7.time, 281474976710656000000)
 
     def test_multiple_arguments(self):
         with self.assertRaises(TypeError):
-            _ = DraftUUID(int=0, hex="061d0edc-bea0-75cc-9892-f6295fd7d295")
+            _ = UUID(int=0, hex="061d0edc-bea0-75cc-9892-f6295fd7d295")
 
 
 if __name__ == "__main__":
